@@ -31,6 +31,7 @@
 
 #include <string.h>
 #include <signal.h>
+#include <stdlib.h>
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -93,6 +94,16 @@ quit_application (GSearchWindow * gsearch)
 	gtk_main_quit ();
 }
 
+void
+version_cb (const gchar * option_name,
+            const gchar * value,
+            gpointer data,
+            GError ** error)
+{
+	g_print ("%s %s\n", g_get_application_name (), VERSION);
+	exit (0);
+}
+
 void
 quit_session_cb (EggSMClient * client,
                  gpointer data)
@@ -276,8 +287,8 @@ constraint_activate_cb (GtkWidget * widget,
 {
 	GSearchWindow * gsearch = data;
 
-	if ((GTK_WIDGET_VISIBLE (gsearch->find_button)) &&
-	    (GTK_WIDGET_SENSITIVE (gsearch->find_button))) {
+	if ((gtk_widget_get_visible (gsearch->find_button)) &&
+	    (gtk_widget_get_sensitive (gsearch->find_button))) {
 		click_find_cb (gsearch->find_button, data);
 	}
 }
@@ -299,8 +310,8 @@ name_contains_activate_cb (GtkWidget * widget,
 {
 	GSearchWindow * gsearch = data;
 
-	if ((GTK_WIDGET_VISIBLE (gsearch->find_button)) &&
-	    (GTK_WIDGET_SENSITIVE (gsearch->find_button))) {
+	if ((gtk_widget_get_visible (gsearch->find_button)) &&
+	    (gtk_widget_get_sensitive (gsearch->find_button))) {
 		click_find_cb (gsearch->find_button, data);
 	}
 }
@@ -354,7 +365,7 @@ display_dialog_file_open_limit (GtkWidget * window,
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
 
 	button = gtk_button_new_from_stock ("gtk-open");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
@@ -551,7 +562,7 @@ display_dialog_folder_open_limit (GtkWidget * window,
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
 
 	button = gtk_button_new_from_stock ("gtk-open");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
@@ -731,7 +742,7 @@ display_dialog_delete_permanently (GtkWidget * window,
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
 
 	button = gtk_button_new_from_stock ("gtk-delete");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
